@@ -11,6 +11,13 @@ import logging
 import uuid
 
 from datetime import datetime
+try:
+    # jupyter_client >= 5, use tz-aware now
+    from jupyter_client.session import utcnow as now
+except ImportError:
+    # jupyter_client < 5, use local now()
+    now = datetime.now
+
 from signal import signal, default_int_handler, SIGINT
 
 import zmq
@@ -220,7 +227,7 @@ class Kernel(SingletonConfigurable):
 
         handler = self.shell_handlers.get(msg_type, None)
         if handler is None:
-            self.log.error("UNKNOWN MESSAGE TYPE: %r", msg_type)
+            self.log.warn("Unknown message type: %r", msg_type)
         else:
             self.log.debug("%s: %s", msg_type, msg)
             self.pre_handler_hook()
@@ -350,8 +357,10 @@ class Kernel(SingletonConfigurable):
 
         Run at the beginning of execution requests.
         """
+        # FIXME: `started` is part of ipyparallel
+        # Remove for ipykernel 5.0
         return {
-            'started': datetime.now(),
+            'started': now(),
         }
 
     def finish_metadata(self, parent, metadata, reply_content):
@@ -643,8 +652,10 @@ class Kernel(SingletonConfigurable):
             status = {'status' : 'aborted'}
             md = {'engine' : self.ident}
             md.update(status)
+            self._publish_status('busy', parent=msg)
             reply_msg = self.session.send(stream, reply_type, metadata=md,
                         content=status, parent=msg, ident=idents)
+            self._publish_status('idle', parent=msg)
             self.log.debug("%s", reply_msg)
             # We need to wait a bit for requests to come in. This can probably
             # be set shorter for true asynchronous clients.
@@ -656,7 +667,7 @@ class Kernel(SingletonConfigurable):
         raise StdinNotImplementedError("raw_input was called, but this "
                                        "frontend does not support stdin.")
 
-    def getpass(self, prompt=''):
+    def getpass(self, prompt='', stream=None):
         """Forward getpass to frontends
 
         Raises
@@ -667,6 +678,10 @@ class Kernel(SingletonConfigurable):
             raise StdinNotImplementedError(
                 "getpass was called, but this frontend does not support input requests."
             )
+        if stream is not None:
+            import warnings
+            warnings.warn("The `stream` parameter of `getpass.getpass` will have no effect when using ipykernel",
+                    UserWarning, stacklevel=2)
         return self._input_request(prompt,
             self._parent_ident,
             self._parent_header,
